@@ -111,8 +111,10 @@ async def _sync_objects(model, company_uuid, source, bss_objs, model_objs, creat
                     createrpc(company_uuid=company_uuid,
                               source=source,
                               source_id=bobj.id,
-                              **{f: m(bobj)
-                                 for f, m in field_map.items()}))
+                              **{
+                                  f: m(bobj)
+                                  for f, m in field_map.items()
+                              }))
                 if mobj:
                     uuid = UUID(bytes=mobj.uuid)
                     logging.info('sync_preseem_model(%s): created %s "%s"', source,
