@@ -6,11 +6,14 @@ from collections import namedtuple
 from icmplib import async_ping
 import ipaddress
 import logging
+import os
 import time
 
 import aiohttp
+import aiohttp.web
 from packaging import version
 from .http_client import HttpClient
+from prometheus_client.exposition import generate_latest
 
 # Set an IPv6 enabled interface for utility code to use.
 # Functions (i.e. parse_ip_value) will check its "ipv6_enabled" var.
@@ -161,7 +164,7 @@ def parse_ip_value(val, max_width=None, strict=False):
                 except ValueError as e:
                     raise ValueError('Error parsing IP network {} ({})'.format(ip, e))
                 if net.prefixlen >= max_width:
-                    if ipv6_enabled or net.version == 6:  # STM-4192 always map IPv6 subnets
+                    if ipv6_enabled or net.version == 6:  # STM-4192 map IPv6 subnets
                         ip_addrs.append(str(net))
                     else:
                         ip_addrs.extend([str(x) for x in net.hosts()])
@@ -334,6 +337,27 @@ async def get_node_versions(telemetry_api):
     return {x[0]: version.parse(x[1].netdev_manager.split()[0]) for x in data.items()}
 
 
+def running_in_container() -> bool:
+    """Check different hints to see if we're running in a container."""
+    return os.getpid() == 1 or os.path.exists('/.dockerenv')
+
+
+class MetricsServer(object):
+    """Run a basic server for metrics and keepalives."""
+
+    def __init__(self, port=9150):
+        self.port = port
+        self.app_metrics = aiohttp.web.Application()
+        self.app_metrics.router.add_route('GET', '/metrics', self.get)
+
+    async def start(self):
+        self.server = await asyncio.get_event_loop().create_server(
+            self.app_metrics.make_handler(access_log=None), '0.0.0.0', self.port)
+
+    async def get(self, request):
+        return aiohttp.web.Response(body=generate_latest(), content_type="text/plain")
+
+
 def run_tool_script(coroutine):
     """Run a Presem tool script - setup the environment properly etc."""
 
@@ -355,7 +379,7 @@ def run_tool_script(coroutine):
         task.result()
     except SystemExit:
         pass
-    except KeyboardInterrupt as e:
+    except KeyboardInterrupt:
         for t in asyncio.Task.all_tasks():
             t.cancel()
     except Exception as err:
@@ -363,7 +387,7 @@ def run_tool_script(coroutine):
     finally:
         try:
             task.result()
-        except BaseException as err:
+        except BaseException:
             pass
         loop.run_until_complete(loop.shutdown_asyncgens())
         loop.close()
