@@ -613,6 +613,10 @@ class TestNetworkElementUpdate(unittest.TestCase):
         del link.bridged_mac_addresses[0]
         self.assertEqual(len(link.bridged_mac_addresses), 0)
 
+        poller_hash = sha256().digest()
+        link.poller_hash = poller_hash
+        self.assertEqual(poller_hash, link.poller_hash)
+
         # Radio
         radio = intf.radios.add()
         radio.id = 'radio1'
@@ -985,6 +989,10 @@ class TestNetworkElementUpdate(unittest.TestCase):
         self.assertEqual(len(wlink.errctx.errors), 2)
         wlink.errctx = None
 
+        poller_hash = sha256().digest()
+        wlink.poller_hash = poller_hash
+        self.assertEqual(poller_hash, wlink.poller_hash)
+
         # Sector
         sector = intf.sectors.add()
 
